package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.projectV2.ZsyzSkxm;
import com.ruoyi.system.service.projectV2.IZsyzSkxmService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_省库项目Controller
 * 
 * @author boman
 * @date 2023-03-28
 */
@RestController
@RequestMapping("/projectV2/skxm")
public class ZsyzSkxmController extends BaseController
{
    @Autowired
    private IZsyzSkxmService zsyzSkxmService;

    /**
     * 查询招商引资_省库项目列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:skxm:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzSkxm zsyzSkxm)
    {
        startPage();
        List<ZsyzSkxm> list = zsyzSkxmService.selectZsyzSkxmList(zsyzSkxm);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_省库项目列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:skxm:export')")
    @Log(title = "招商引资_省库项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzSkxm zsyzSkxm)
    {
        List<ZsyzSkxm> list = zsyzSkxmService.selectZsyzSkxmList(zsyzSkxm);
        ExcelUtil<ZsyzSkxm> util = new ExcelUtil<ZsyzSkxm>(ZsyzSkxm.class);
        util.exportExcel(response, list, "招商引资_省库项目数据");
    }

    /**
     * 获取招商引资_省库项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:skxm:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzSkxmService.selectZsyzSkxmById(id));
    }

    /**
     * 新增招商引资_省库项目
     */
    @PreAuthorize("@ss.hasPermi('projectV2:skxm:add')")
    @Log(title = "招商引资_省库项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzSkxm zsyzSkxm)
    {
        return toAjax(zsyzSkxmService.insertZsyzSkxm(zsyzSkxm));
    }

    /**
     * 修改招商引资_省库项目
     */
    @PreAuthorize("@ss.hasPermi('projectV2:skxm:edit')")
    @Log(title = "招商引资_省库项目", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzSkxm zsyzSkxm)
    {
        return toAjax(zsyzSkxmService.updateZsyzSkxm(zsyzSkxm));
    }

    /**
     * 删除招商引资_省库项目
     */
    @PreAuthorize("@ss.hasPermi('projectV2:skxm:remove')")
    @Log(title = "招商引资_省库项目", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzSkxmService.deleteZsyzSkxmByIds(ids));
    }
}
